@@ -2,7 +2,7 @@ package Net::Twitter::OAuth;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use base qw( Net::Twitter );
 
@@ -27,6 +27,12 @@ sub new {
     $self;
 }
 
+sub oauth {
+    my $self = shift;
+    $self->{oauth};
+}
+
+# shortcuts defined in early releases
 sub oauth_token {
     my($self, @tokens) = @_;
     $self->{oauth}->access_token($tokens[0]);
@@ -69,23 +75,8 @@ Net::Twitter::OAuth - Net::Twitter subclass that uses OAuth instead of Basic Aut
       consumer_secret => "YOUR-CONSUMER-SECRET",
   );
 
-  # You'll save these token and secret in cookie, config file or session database
-  my($access_token, $access_token_secret) = restore_tokens();
-  if ($access_token && $access_token_secret) {
-      $client->oauth_token($access_token, $access_token_secret);
-  }
+  # Do some Authentication work. See EXAMPLES
 
-  unless ($client->is_authorized) {
-      # The client is not yet authorized: Do it now
-      print "Authorize this app at ", $client->oauth_authorize_url, " and hit RET\n";
-
-      <STDIN>; # wait for input
-
-      my($access_token, $access_token_secret) = $client->request_access_token;
-      save_tokens($access_token, $access_token_secret); # if necessary
-  }
-
-  # Everything's ready: same as Net::Twitter
   my $tweets = $client->friends_timeline;
   my $res    = $client->update({ status => "I CAN HAZ OAUTH!" });
 
@@ -96,6 +87,91 @@ authentication instead of the default Basic Authentication.
 
 Note that this client only works with APIs that are compatible to OAuth authentication.
 
+=head1 EXAMPLES
+
+Here's how to authorize users as a desktop app mode:
+
+  use Net::Twitter::OAuth;
+
+  my $client = Net::Twitter::OAuth->new(
+      consumer_key    => "YOUR-CONSUMER-KEY",
+      consumer_secret => "YOUR-CONSUMER-SECRET",
+  );
+
+  # You'll save these token and secret in cookie, config file or session database
+  my($access_token, $access_token_secret) = restore_tokens();
+  if ($access_token && $access_token_secret) {
+      $client->oauth->access_token($access_token);
+      $client->oauth->access_token_secret($access_token_secret);
+  }
+
+  unless ($client->oauth->authorized) {
+      # The client is not yet authorized: Do it now
+      print "Authorize this app at ", $client->oauth->get_authorization_url, " and hit RET\n";
+
+      <STDIN>; # wait for input
+
+      my($access_token, $access_token_secret) = $client->oauth->request_access_token;
+      save_tokens($access_token, $access_token_secret); # if necessary
+  }
+
+  # Everything's ready
+
+In a web application mode, you need to save the oauth_token and
+oauth_token_secret somewhere when you redirect the user to the OAuth
+authorization URL.
+
+  sub twitter_authorize : Local {
+      my($self, $c) = @_;
+
+      my $client = Net::Twitter::OAuth->new(%param);
+      my $url = $client->oauth->get_authorization_url;
+
+      $c->response->cookies->{oauth} = {
+          value => {
+              token => $client->oauth->request_token,
+              token_secret => $client->oauth->request_token_secret,
+          },
+      };
+
+      $c->response->redirect($url);
+  }
+
+And when the user returns back, you'll reset those request token and
+secret to upgrade the request token to access token.
+
+  sub twitter_auth_callback : Local {
+      my($self, $c) = @_;
+
+      my $cookie = $c->response->cookies->{oauth}->value;
+
+      my $client = Net::Twitter::OAuth->new(%param);
+      $client->oauth->request_token($client->{token});
+      $client->oauth->request_token_secret($client->{token_secret});
+
+      my($access_token, $access_token_secret)
+          = $client->oauth->request_access_token;
+
+      # Save $access_token and $access_token_secret in the database associated with $c->user
+  }
+
+Later on, you can retrieve and reset those access token and secret
+before calling any Twitter API methods.
+
+  sub make_tweet : Local {
+      my($self, $c) = @_;
+
+      my($access_token, $access_token_secret) = ...;
+
+      my $client = Net::Twitter::OAuth->new(%param);
+      $client->oauth->access_token($access_token);
+      $client->oauth->access_token_secret($access_token_secret);
+
+      # Now you can call any Net::Twitter API methods on $client
+      my $status = $c->req->param('status');
+      my $res = $client->update({ status => $status });
+  }
+
 =head1 METHODS
 
 =over 4
@@ -111,36 +187,12 @@ Creates a new Net::Twitter::OAuth object. Takes the parameters
 C<consumer_key> and C<consumer_secret> that can be acquired at Twitter
 Developer screen L<http://twitter.com/oauth_clients>.
 
-=item oauth_token
+=item oauth
 
-  $client->oauth_token($access_token, $access_token_secret);
+  $client->oauth;
 
-Sets access token and secret, saved in your app's local storage
-(e.g. config file, cookie or session database). This allows you to
-call APIs once the application is authorized by the user.
-
-=item is_authorized
-
-  $client->is_authorized;
-
-Returns the state if the app is already authorized to access APIs. If
-this returns false, you should call I<oauth_authorize_url> etc. to let
-user authorize the application.
-
-=item oauth_authorize_url
-
-  my $url = $client->oauth_authorize_url;
-
-Returns the URL where the end user is asked to authorize the application.
-
-=item request_access_token
-
-  my($access_token, $access_token_secret) = $client->request_access_token;
-
-Once the application is authorized by the user, your code should call
-this method to exchange the generic token to access token for later
-API calls. You probably want to save these token in a local storage so
-that you can skip the authorization phase for the next run.
+Returns Net::OAuth::Simple object to deal with getting and setting
+OAuth tokens. See L<Net::OAuth::Simple> for details.
 
 =back
 
